A simulation model gathers information required to run the simulation.
It includes:
initial-snpashot snapshot to start the model with.middlewares sequence of middleware to execute with the model.model-data data version of this model.ordering ordering of events.registry registry.stopping-criterias list of stopping-criteria that defines the end of the model.A simulation model gathers information required to run the simulation. It includes: * `initial-snpashot` snapshot to start the model with. * `middlewares` sequence of middleware to execute with the model. * `model-data` data version of this model. * `ordering` ordering of events. * `registry` registry. * `stopping-criterias` list of `stopping-criteria` that defines the end of the model.
(build {:keys [initial-event-type initial-bucket middlewares ordering
stopping-criterias]
:or {initial-bucket 0}
:as model-data}
registry)Turns model-data into a model.
Retuns the model's.
Turns `model-data` into a `model`. Retuns the `model`'s.
(validate model)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |